@@ -23,6 +23,9 @@
 /* Default runtime library to use. */
 #define CLANG_DEFAULT_RTLIB ""
 
+/* Default unwind library to use. */
+#define CLANG_DEFAULT_UNWINDLIB ""
+
 /* Default objcopy to use */
 #define CLANG_DEFAULT_OBJCOPY "objcopy"
 
@@ -54,14 +57,11 @@
 /* Define if we have libxml2 */
 #define CLANG_HAVE_LIBXML 1
 
-/* Define if we have z3 and want to build it */
-/* #undef CLANG_ANALYZER_WITH_Z3 */
-
 /* Define if we have sys/resource.h (rlimits) */
 #define CLANG_HAVE_RLIMITS 1
 
 /* The LLVM product name and version */
-#define BACKEND_PACKAGE_STRING "LLVM 7.0.1"
+#define BACKEND_PACKAGE_STRING "LLVM 10.0.0"
 
 /* Linker version detected at compile time. */
 /* #undef HOST_LINK_VERSION */
@@ -80,4 +80,7 @@
 #define CLANG_ENABLE_OBJC_REWRITER 1
 #define CLANG_ENABLE_STATIC_ANALYZER 1
 
+/* Spawn a new process clang.exe for the CC1 tool invocation, when necessary */
+#define CLANG_SPAWN_CC1 0
+
 #endif
